Skip to contents

Print method for targeter objects

Usage

# S3 method for class 'targeter'
print(x, ...)

Arguments

x

targeter object

...

additional arguments

Details

This method prints the targeter object, including the target, data name, date, and number of profiles available.