Skip to contents

summary method for crossvar object

Usage

# S3 method for class 'crossvar'
summary(
  object,
  extra_stats = FALSE,
  which_minmax = as.character(object$target_reference_level),
  ...
)

Arguments

object

an object of class targeter

extra_stats

boolean - whether function returns some additional associations statistics (default: FALSE)

which_minmax

defines which target level is used as reference/target for minmax computations

...

additional parameters (currently not used)

Value

a one-row data.table

Details

Returned table contains one row for the crossvar explanatory variable analyzed in targeter and columns for associations measures / metrics.

Examples

 data(adult)
 x <- crossvar(adult, target='HOURSPERWEEK', var='FNLWGT')
#> 
#> INFO:target HOURSPERWEEK detected as type: numeric
summary(x)
#>   varname   targetname vartype           IV  highest_impact
#> 1  FNLWGT HOURSPERWEEK numeric 0.0001006458 [+] over-target
summary(x, extra_stats = TRUE)
#>   varname   targetname vartype           IV  highest_impact        F
#> 1  FNLWGT HOURSPERWEEK numeric 0.0001006458 [+] over-target 3.490284
#>            pval
#> 1 0.00006759324