This function checks that the naming convention used by WeLoveDataScience are respected for each column.
Value
a table which contains two columns "ErrorType" and "ErrorTarget". Each row corresponds to a variable of the data. The column "ErrorType" == FALSE when the condition on the first letter is respected. The column "ErrorTarget" == FALSE when the condition on BIN/INT/ORD/CAT on the target is respected