R/print.R
print.targeter.Rd
Print method for targeter objects
# S3 method for class 'targeter' print(x, ...)
targeter object
additional arguments
This method prints the targeter object, including the target, data name, date, and number of profiles available.